og-fetcher
==========
Simple Open Graph fetcher for python without any dependency

Usage
-----
.. code:: python

  from og_fetcher.fetch import fetch

  og_data = fetch('http://ogp.me')

Installation
------------
.. code::

  pip install og-fetcher
